PohRuntime class

Constructors

PohRuntime()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

changeDirectory(String path) bool
createDirectory(String path) bool
deleteDirectory(String path) bool
deleteFile(String path) bool
inputInt(String name) int?
inputText(String name) String?
listFiles(String dirPath) List<String>
randomBetween(num a, num b) num
readFile(String path) String
runProgramBackground(String command) Future<Process?>
runProgramWait(String command) Future<int>
writeFile(String path, String content, {bool append = false}) bool